package com.iden.bms.service;


import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.iden.common.entity.*;
import com.iden.common.enums.HandleWarningStatusEnum;
import com.iden.common.enums.WarningTypeEnum;
import com.iden.common.exception.BDException;


import com.iden.common.service.*;
import com.iden.common.util.DateUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;


import java.util.Date;
import java.util.List;

/**
 *
 * @author makejava
 * @since 2021-05-21 00:08:38
 */
@Service
public class WarningService {

    @Resource
    private IdenFaceImageService idenFaceImageService;
    @Resource
    private IdenCameraService idenCameraService;
    @Resource
    private IdenCommunityService idenCommunityService;
    @Resource
    private IdenWarningEventService idenWarningEventService;
    @Resource
    private IdenWarningPersonService idenWarningPersonService;
    @Resource
    private IdenWarningPersonTraceService idenWarningPersonTraceService;
    @Resource
    private IdenWarningStaService idenWarningStaService;

    /**
     * 处理预警
     * @return
     */
    public void handleWarning() throws BDException {
      //查询没有处理过的人脸图像数据
        QueryWrapper<IdenFaceImage> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(IdenFaceImage::getHandleWarningStatus, HandleWarningStatusEnum.NO_HANDLE.getValue())
        .last("limit 5000"); //每次处理5000条
        List<IdenFaceImage> idenFaceImageList = idenFaceImageService.list(queryWrapper);
        if (CollUtil.isEmpty(idenFaceImageList)) {
            return;
        }

        for (IdenFaceImage idenFaceImage : idenFaceImageList) {

            String type = idenFaceImage.getType();
            if (StringUtils.isNotEmpty(type) && type.contains("0")) { //陌生人员

            }
            else if (StringUtils.isNotEmpty(type) && type.contains("1")) { //重点人员
                IdenWarningPerson idenWarningPerson = new IdenWarningPerson();
                idenWarningPerson.setImage(idenFaceImage.getImage());
                idenWarningPerson.setDataDate(DateUtils.strToDate(DateUtils.formatToDateStr(idenFaceImage.getPhotographTime(),"yyyy-MM-dd"),"yyyy-MM-dd"));
                Long cameraId = idenFaceImage.getCameraId();
                if(cameraId != null) {
                    IdenCamera idenCamera = this.idenCameraService.getById(cameraId);
                    idenWarningPerson.setCommunityName(idenCamera.getDistrict());
                    idenWarningPerson.setSubdistrict(idenCamera.getSubdistrict());
                }
                Long communityId = idenFaceImage.getCommunityId();
                if(communityId != null) {
                    IdenCommunity idenCommunity = this.idenCommunityService.getById(communityId);
                    if (idenCommunity != null) {
                        idenWarningPerson.setCommunityId(communityId);
                        idenWarningPerson.setCommunityCode(idenCommunity.getCode());
                        idenWarningPerson.setCommunityName(idenCommunity.getName());
                    }
                }
                idenWarningPerson.setAppearFrequency(1);
                idenWarningPerson.setEarliestAppearTime(idenFaceImage.getPhotographTime());
                idenWarningPerson.setType(WarningTypeEnum.KEYNOTE.getValue());
                idenWarningPerson.setPersonId(idenFaceImage.getPersonId());
                idenWarningPerson.setCreateTime(idenFaceImage.getCreateTime());
                this.idenWarningPersonService.save(idenWarningPerson);

                IdenWarningEvent idenWarningEvent = new IdenWarningEvent();
                idenWarningEvent.setWarningPersonId(idenWarningPerson.getId());
                idenWarningEvent.setDataTime(idenFaceImage.getPhotographTime());
                idenWarningEvent.setImage(idenFaceImage.getImage());
                idenWarningEvent.setCommunityId(idenWarningPerson.getCommunityId());
                idenWarningEvent.setCommunityCode(idenWarningPerson.getCommunityCode());
                idenWarningEvent.setCommunityName(idenWarningPerson.getCommunityName());
                idenWarningEvent.setCommunityName(idenWarningPerson.getDistrict());
                idenWarningEvent.setSubdistrict(idenWarningPerson.getSubdistrict());
                idenWarningEvent.setAppearTime(idenFaceImage.getPhotographTime());
                idenWarningEvent.setType(WarningTypeEnum.KEYNOTE.getValue());
                idenWarningEvent.setPersonId(idenFaceImage.getPersonId());
                idenWarningEvent.setCreateTime(idenFaceImage.getCreateTime());
                this.idenWarningEventService.save(idenWarningEvent);

                IdenWarningPersonTrace idenWarningPersonTrace = new IdenWarningPersonTrace();
                BeanUtil.copyProperties(idenFaceImage,idenWarningPersonTrace,"id");
                idenWarningPersonTrace.setWarningPersonId(idenWarningPerson.getId());
                this.idenWarningPersonTraceService.save(idenWarningPersonTrace);
            }
            else if (StringUtils.isNotEmpty(type) && type.contains("2")) { //小区人员

            }
            else if (StringUtils.isNotEmpty(type) && type.contains("3")) { //昼伏夜出人员

            }
        }

    }


}